@@ -12,6 +12,9 @@ except:
 nltk.download('stopwords')
 nltk.download('punkt')
 
+nltk.download('wordnet')
+nltk.download('wordnet', download_dir=str(Path(__file__).parent) +'/saved')
+nltk.data.path.append(str(Path(__file__).parent) +'/saved/corpora/wordnet')
 
 if not os.path.exists(str(Path(__file__).parent) +'/saved/corpora/wordnet'):
 	nltk.download('wordnet', download_dir=str(Path(__file__).parent) +'/saved')
@@ -244,7 +247,7 @@ class DataframeClean(Aspectanalyze):
         clean_df = self.file.copy().dropna()
 
         clean_df["reviewText"] = (
-            clean_df["reviewText"]
+            clean_df[self.column_name]
             .apply(lambda x: self.stop_words_removal(x, self.common_titles,self.wnl))
             .dropna()
         )
